#!/bin/bash
# packager         : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location  : http://jak-linux.org/projects/ndisgtk/
# last revised     : 2.4.2010

softname='ndisgtk'
softversion='0.8.5'
packageversion='64.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://jak-linux.org/projects/ndisgtk/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
ndisgtk: ndisgtk - frontend to install ndis drivers
ndisgtk: 
ndisgtk: With ndisgtk you can easily install an NDIS driver for your WIFI 
ndisgtk: card when it is not supported natively in the Linux kernel. The
ndisgtk: ndiswrapper module must be loaded before you can proceed.
ndisgtk:  
ndisgtk: 
ndisgtk: 
ndisgtk: 
ndisgtk: 
ndisgtk:
EOF

#
# check if source is present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xzvf $srcpkg
cd $src

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    sed 's/network-admin/wicd/' -i ndisgtk
	sed 's/Windows/Ndiswrapper/' -i ndisgtk.desktop.in
	sed 's/Windows/Ndiswrapper/' -i ndisgtk-kde.desktop.in
	sed 's/.png//' -i ndisgtk.desktop.in
	sed 's/.png//' -i ndisgtk-kde.desktop.in
	sed 's/Windows/Ndiswrapper/' -i ndisgtk.glade
	cd po
	sed 's/Windows/Ndiswrapper/' -i ndisgtk.pot
	sed 's/Windows/Ndiswrapper/' -i *po

    cd $src 
    
    make
    make install DESTDIR=$dest
    
# add 'default' files
    cp -a \
      NEWS \
      $dest/usr/doc/$softname-$softversion

# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 640 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -type d -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# dep file
echo -e "intltool,ndiswrapper,python,wicd" > $package.dep

# erase source
rm -rf $src
rm -rf $dest

# generate source file
echo http://users.zenwalk.org/user-accounts/bip/ISO/xap/ndisgtk/source/build-ndiskgtk.sh > $package.src
echo $source >>$package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
